aboutsummaryrefslogtreecommitdiffstats
path: root/epan/epan.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/epan.h')
-rw-r--r--epan/epan.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/epan/epan.h b/epan/epan.h
index 41bf18e437..1c743e80f3 100644
--- a/epan/epan.h
+++ b/epan/epan.h
@@ -206,11 +206,16 @@ void
epan_dissect_file_run_with_taps(epan_dissect_t *edt, struct wtap_pkthdr *phdr,
tvbuff_t *tvb, frame_data *fd, struct epan_column_info *cinfo);
/** Prime a proto_tree using the fields/protocols used in a dfilter. */
WS_DLL_PUBLIC
void
epan_dissect_prime_dfilter(epan_dissect_t *edt, const struct epan_dfilter *dfcode);
+/** Prime an epan_dissect_t's proto_tree with a field/protocol specified by its hfid */
+WS_DLL_PUBLIC
+void
+epan_dissect_prime_hfid(epan_dissect_t *edt, int hfid);
+
/** fill the dissect run output into the packet list columns */
WS_DLL_PUBLIC
void
@@ -206,11 +206,16 @@ void
epan_dissect_file_run_with_taps(epan_dissect_t *edt, struct wtap_pkthdr *phdr,
tvbuff_t *tvb, frame_data *fd, struct epan_column_info *cinfo);
-/** Prime a proto_tree using the fields/protocols used in a dfilter. */
+/** Prime an epan_dissect_t's proto_tree using the fields/protocols used in a dfilter. */
WS_DLL_PUBLIC
void